function A = rrefmod2(A)
%RREF   Reduced row echelon form.
%   R = RREF(A) produces the reduced row echelon form of A.
%
%   [R,jb] = RREF(A) also returns a vector, jb, so that:
%       r = length(jb) is this algorithm's idea of the rank of A,
%       x(jb) are the bound variables in a linear system, Ax = b,
%       A(:,jb) is a basis for the range of A,
%       R(1:r,jb) is the r-by-r identity matrix.
%
%   [R,jb] = RREF(A,TOL) uses the given tolerance in the rank tests.
%
%   Roundoff errors may cause this algorithm to compute a different
%   value for the rank than RANK, ORTH and NULL.
%
%   See also RREFMOVIE, RANK, ORTH, NULL, QR, SVD.

%   CBM, 11/24/85, 1/29/90, 7/12/92.
%   Copyright 1984-2002 The MathWorks, Inc. 
%   $Revision: 5.9 $  $Date: 2002/04/08 23:51:52 $

A = mod (A, 2);

[m,n] = size(A);

% Loop over the entire matrix.
i = 1;
j = 1;

while (i <= m) & (j <= n)
   % Find value and index of largest element in the remainder of column j.
   [p,k] = max(abs(A(i:m,j))); k = k+i-1;
   % Swap i-th and k-th rows.
   A([i k],j:n) = A([k i],j:n);
   % Subtract multiples of the pivot row from all the other rows.
   for k = [1:i-1 i+1:m]
      A(k,j:n) = mod(A(k,j:n) - A(k,j)*A(i,j:n), 2);
   end
   i = i + 1;
   j = j + 1;
end

% A = mod(A,2)
% Return "rational" numbers if appropriate.